@@ -1,4 +1,6 @@
 from . import word
 from . import pdf
 from . import image
-from . import file
\ No newline at end of file
+from . import file
+from . import video
+from . import tools
\ No newline at end of file
